KG2E
====

.. currentmodule:: pykeen.models

.. autoclass:: KG2E
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~KG2E.constrainer_default_kwargs
      ~KG2E.hpo_default

   .. rubric:: Attributes Documentation

   .. autoattribute:: constrainer_default_kwargs
   .. autoattribute:: hpo_default
